@@ -106,6 +106,25 @@
 #' # Example of javascript async call
 #' jsscript <- "arguments[arguments.length - 1](arguments[0] + arguments[1]);"
 #' remDr$executeAsyncScript(jsscript, args = 1:2)
+#' 
+#' # EXAMPLE INJECTING INTO PHANTOMJS using phantomExecute
+#' require(RSelenium)
+#' pJS <- phantom()
+#' remDr <- remoteDriver(browserName = "phantomjs")
+#' remDr$open(silent = TRUE)
+#' remDr$navigate("http://ariya.github.com/js/random/")
+#' remDr$findElement("id", "numbers")$getElementText()[[1]] # returns a set of random numbers
+#  # now try injecting a new Math,random function
+#' result = remDr$phantomExecute("var page = this;
+#'                                page.onInitialized = function () {
+#'                                page.evaluate(function () {
+#'                                Math.random = function() { return 42 / 100 }
+#'                                })
+#'                                }", list());
+#' remDr$navigate("http://ariya.github.com/js/random/")
+#' remDr$findElement("id", "numbers")$getElementText()[[1]] # Math.random returns our custom function
+#' remDr$close()
+#' pJS$stop()
 #' }
 #' 
 
@@ -691,9 +710,12 @@ remoteDriver <- setRefClass("remoteDriver",
                                 .self$value
                               },
                               
-                              phantomExecute = function(script, args){
+                              phantomExecute = function(script, args = list()){
+                                "This API allows you to send a string of JavaScript via 'script', written for PhantomJS, and be interpreted within the context of a WebDriver Page. In other words, for the given script then this variable is initialized to be the current Page.
+                                See \\url{https://github.com/ariya/phantomjs/wiki/API-Reference-WebPage} and the example in this help file. NOTE: Calling the PhantomJS API currently only works when PhantomJS is driven directly via \\code{\\link{phantom}}"
                                 queryRD(paste0(serverURL,'/session/',sessionInfo$id,'/phantom/execute'),
                                         "POST",qdata = toJSON(list(script = script, args = args)))
+                                .self$value
                               },
                               
                               closeServer = function(){
